@@ -184,6 +184,175 @@ class MongodbHelper(BaseSqlHelper):
             return rs[0]
         return None
 
+    def sync_insert_data(self, table_name: str, data):
+        """
+        对于插入接口的整合，不需要考虑是单条插入还是多条插入，自动区分
+        :param table_name:
+        :param data:
+        :return:
+        """
+        if isinstance(data, list):
+            if len(data) == 1:
+                return self.insert_one_data(table_name, data[0])
+            else:
+                return self.sync_insert_many_data(table_name, data)
+        elif isinstance(data, dict):
+            return self.insert_one_data(table_name, data)
+
+    def sync_insert_one_data(self, table_name: str, data: dict):
+        """
+        新增记录插入
+        :param table_name: 表名
+        :param data: 待插入数据
+        :return:
+        """
+        db_str, collection_str = table_name.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        collection.insert_one(data)
+        return {"rowcount": 1}
+
+    def sync_insert_many_data(self, table_name: str, data: list):
+        """
+        批量插入
+        :param table_name:
+        :param data:
+        :return:
+        """
+        db_str, collection_str = table_name.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        rs = collection.insert_many(data)
+        return {"rowcount": len(rs.inserted_ids)}
+
+    def sync_update_data(self, condition_wrapper: ConditionWrapper, param: dict):
+        """
+        按条件更新
+        :param condition_wrapper: 更新条件
+        :param param:更新值
+        :return:
+        """
+        db_str, collection_str = condition_wrapper.table.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        filter_items = self.prepare_condition_sql(condition_wrapper.conditions)
+        rs = collection.update_many(filter_items, {"$set": param})
+        return {"rowcount": rs.modified_count}
+
+    def sync_delete_data(self, condition_wrapper: ConditionWrapper):
+        """
+        按条件删除
+        :param condition_wrapper: 删除条件
+        :return:
+        """
+        db_str, collection_str = condition_wrapper.table.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        filter_items = self.prepare_condition_sql(condition_wrapper.conditions)
+        rs = collection.delete_many(filter_items)
+        return {"rowcount": rs.deleted_count}
+
+    def sync_fetchone_data(self, condition_wrapper: ConditionWrapper):
+        """
+        查询单条数据
+        :param condition_wrapper:  查询条件信息
+        :return:
+        """
+        db_str, collection_str = condition_wrapper.table.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        aggregate = self.prepare_query_sql(condition_wrapper)
+        return self.sync_execute_fetchone(aggregate, {"collection": collection})
+
+    def sync_fetchall_data(self, condition_wrapper: ConditionWrapper):
+        """
+        查询多条数据
+        :param condition_wrapper: 查询条件信息
+        :return:
+        """
+        db_str, collection_str = condition_wrapper.table.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        aggregate = self.prepare_query_sql(condition_wrapper)
+        rs = self.sync_execute_fetchall(aggregate, {"collection": collection, "length": options.max_limit})
+        return rs
+
+    def sync_fetchall_page(self, condition_wrapper: ConditionWrapper, page_num=1, page_size=10):
+        """
+        分页查询多条数据
+        :param condition_wrapper:
+        :param page_num: 当前页码
+        :param page_size: 每页数量
+        :return:
+        """
+        db_str, collection_str = condition_wrapper.table.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        aggregate, count_ = self.prepare_page_sql(condition_wrapper, page_num, page_size)
+        records = self.sync_execute_fetchall(aggregate, {"collection": collection, "length": int(page_size)})
+        # 查询记录数量
+        total_result = self.sync_execute_fetchone(count_, {"collection": collection})
+        # 组装成page包装类 最终转为 dict 类型 为转换json
+        return Page(records=records, current=page_num, page_size=page_size,
+                    total=total_result.get("total", 0) if total_result else 0).__dict__
+
+    @echo_sql
+    def sync_execute_fetchone(self, sql: str, param=None):
+        """
+        查询单条数据
+        :param sql: 待执行的Sql语句
+        :param param: 参数
+        :return:
+        """
+        cursor = param["collection"].aggregate(sql)
+        rs = list(cursor)
+        if len(rs) > 0:
+            return rs[0]
+        return None
+
+    @echo_sql
+    def sync_execute_fetchall(self, sql: str, param=None):
+        """
+        查询多条数据
+        :param sql: 待执行的Sql语句
+        :param param: 参数
+        :return:
+        """
+        cursor = param["collection"].aggregate(sql)
+        return list(cursor)
+
+    @echo_sql
+    def sync_execute_fetch(self, db_collection, sql: str, length=10000):
+        """
+        查询多条数据
+        :param sql: 待执行的Sql语句
+        :param param: 参数
+        :return:
+        """
+        db_str, collection_str = db_collection.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        cursor = collection.aggregate(sql)
+        return list(cursor)
+
+    @echo_sql
+    def sync_execute_fetch_one(self, db_collection, sql):
+        """
+        查询单条数据
+        :param sql: 待执行的Sql语句
+        :param param: 参数
+        :return:
+        """
+        db_str, collection_str = db_collection.split(".")
+        db = self.pool[db_str]
+        collection = db[collection_str]
+        # collection.find_one(find_condition)
+        cursor = collection.aggregate(sql)
+        rs = list(cursor)
+        if len(rs) > 0:
+            return rs[0]
+        return None
+
     def prepare_insert_sql(self, table_name: str, item: dict):
         """
         组装插入sql
@@ -325,3 +494,9 @@ class MongodbHelper(BaseSqlHelper):
 
     async def executemany_sql(self, sql: str, param=None):
         pass
+
+    def sync_execute_sql(self, sql: str, param=None):
+        pass
+
+    def sync_executemany_sql(self, sql: str, param=None):
+        pass
