@@ -8,7 +8,8 @@ python_column_type_dict = {
     "str": "string",
     "int": "integer",
     "dict": "object",
-    "bool": "boolean"
+    "bool": "boolean",
+    "float": "multipleOf"
 }
 definitions = {}
 
