@@ -20,11 +20,8 @@ async def post(path, data=None,
             async with session.post(base_url + path, json=data, **kwargs) as resp:
                 if result_type == "json":
                     result = await resp.json()
-                    if result.get("status") == "00000":
-                        if not pack:
-                            result = result.get("data")
-                    else:
-                        raise Exception(json.dumps(result))
+                    if result.get("status") == "00000" and not pack:
+                        result = result.get("data")
                 elif result_type == "text":
                     result = await resp.text()
                 else:
@@ -34,7 +31,7 @@ async def post(path, data=None,
             async with session.post(base_url + path, data=data, **kwargs) as resp:
                 if result_type == "json":
                     result = await resp.json()
-                    if not pack:
+                    if result.get("status") == "00000" and not pack:
                         result = result.get("data")
                 elif result_type == "text":
                     result = await resp.text()
@@ -49,11 +46,8 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
         async with session.get(base_url + path, params=params, **kwargs) as resp:
             if result_type == "json":
                 result = await resp.json()
-                if result.get("status") == "00000":
-                    if not pack:
-                        result = result.get("data")
-                else:
-                    raise Exception(json.dumps(result))
+                if result.get("status") == "00000" and not pack:
+                    result = result.get("data")
             elif result_type == "text":
                 result = await resp.text()
             else:
@@ -65,11 +59,8 @@ def sync_get(path, params=None, base_url=tornado.options.options.data_server, re
     res = requests.get(base_url + path, params=params, **kwargs)
     if result_type == "json":
         res = res.json()
-        if res.get("status") == "00000":
-            if not pack:
-                res = res.get("data")
-        else:
-            raise Exception(json.dumps(res))
+        if res.get("status") == "00000" and not pack:
+            res = res.get("data")
     elif result_type == "text":
         res = res.text
     else:
@@ -91,11 +82,8 @@ def sync_post(path, data=None,
         res = requests.post(base_url + path, data=data, **kwargs)
     if result_type == "json":
         res = res.json()
-        if res.get("status") == "00000":
-            if not pack:
-                res = res.get("data")
-        else:
-            raise Exception(json.dumps(res))
+        if res.get("status") == "00000" and not pack:
+            res = res.get("data")
     elif result_type == "text":
         res = res.text
     else:
@@ -113,10 +101,8 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
     res = eureka_client.do_service(app_name=app_name, service=path, return_type=return_type, method=method, data=data,
                                    **kwargs)
     if return_type == "json" and not pack:
-        if res.get("status") == "00000":
+        if res.get("status") == "00000" and not pack:
             res = res.get("data")
-        else:
-            raise Exception(json.dumps(res))
     return res
 
 
